@@ -361,7 +361,7 @@ void drumkv1_jack::open ( const char *client_name )
 #endif	// CONFIG_ALSA_MIDI
 
 	// setup any local, initial buffers...
-	drumkv1::setBufferSize(::jack_get_buffer_size(m_client));
+	drumkv1::setBufferSize(::jack_get_buffer_size(m_client) << 2);
 
 	::jack_set_buffer_size_callback(m_client,
 		drumkv1_jack_buffer_size, this);
@@ -728,7 +728,7 @@ static void drumkv1_sigterm_handler ( int /*signo*/ )
 {
 	char c = 1;
 
-	(::write(g_fdSigterm[0], &c, sizeof(c)) > 0);
+	(void) (::write(g_fdSigterm[0], &c, sizeof(c)) > 0);
 }
 
 #endif	// HAVE_SIGNAL_H
@@ -753,6 +753,9 @@ drumkv1_jack_application::drumkv1_jack_application ( int& argc, char **argv )
 	}
 
 	if (m_bGui) {
+	#if defined(Q_OS_LINUX)
+		::setenv("QT_QPA_PLATFORM", "xcb", 0);
+	#endif
 	#if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
 	#if QT_VERSION <  QT_VERSION_CHECK(6, 0, 0)
 		QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
